#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 filtrable
version:              0.1.6.0
visibility:           public
id:                   filtrable-0.1.6.0-2HtSqkdNbUoGiIjqJ7uakz
key:                  filtrable-0.1.6.0-2HtSqkdNbUoGiIjqJ7uakz
license:              BSD-3-Clause
maintainer:           strake888@gmail.com
author:               M Farkas-Dyck
homepage:             https://github.com/strake/filtrable.hs
synopsis:             Class of filtrable containers
description:          See "Data.Filtrable".
category:             Data
abi:                  bf13c3c9b6a5d748606a0117d721c767
exposed:              True
exposed-modules:      Data.Filtrable
hidden-modules:       Data.Set.Private
import-dirs:          /usr/lib/ghc-9.6.6/site-local/filtrable-0.1.6.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/filtrable-0.1.6.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/filtrable-0.1.6.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-filtrable
hs-libraries:         HSfiltrable-0.1.6.0-2HtSqkdNbUoGiIjqJ7uakz
depends:              base-4.18.2.1 containers-0.6.7 transformers-0.6.1.0
haddock-interfaces:   /usr/share/doc/haskell-filtrable/html/filtrable.haddock
haddock-html:         /usr/share/doc/haskell-filtrable/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

